****Demo 2 - Report Destinations and Options****;

/*********************************************************/
/*  Part A - Send output to 5 destinations               */
/* Note the SAS/Graph options on the title.           */
/********************************************************/
libname demo 'c:\data\learning labs\ods';
ods html file='c:\data\learning labs\ods\output\demo2a.html';
ods pdf file='c:\data\learning labs\ods\output\demo2a.pdf';
ods rtf file='c:\data\learning labs\ods\output\demo2a.rtf';
*  For Excel;
ods csv file='c:\data\learning labs\ods\output\demo2a_csv.csv';
ods html3 file='c:\data\learning labs\ods\output\demo2a_xls.xls';
proc freq data=demo.employees;
 tables jobcode;
run;
proc tabulate data=demo.employees;
 title color=red h=4 'Employee Salaries by country and jobcode';
 where empcountry in ('AUSTRALIA', 'ITALY' 'JAPAN');
   class jobcode empcountry;
    var salary;
   table jobcode, empcountry*salary=' '*(n mean);
run;
ods _all_ close;
ods listing;



/**********************************************************/
/*  Part B - HTML options to create a FRAME .        */
/* ODS Proclabel and contents= option to change  */
/*  labeling in results window, PDF bookmark tree, */
/*  and HTML contents page.                                  */
/**********************************************************/
title; footnote; ods _all_ close;
ods html path='c:\data\learning labs\ods\output' (url=none)
               file='demo2b.html'
               frame='frame.html'
               contents='toc.html'
			   page='page.html';
ods proclabel 'Tabular report ';
proc tabulate data=demo.employees
                       contents='Analysis of salaries';                      
 title color=red h=3 'Employee Salaries Analysis';
 where empcountry in ('AUSTRALIA', 'ITALY' 'JAPAN');
 class jobcode empcountry;
 var salary; 
 * Contents= options allows labelling of each table in TOC;
 table jobcode, empcountry*salary=' '*(n mean)/
                         contents='By Country and Jobcode'; 
 table jobcode*salary=' '*(n mean)/contents='By Jobcode';
run;

ods proclabel 'Graphics report';
goptions device=activex;
Proc gchart data=demo.employees ;
title 'Employee Salaries by Jobcode';
where empcountry in ('CANADA' 'USA' 'FRANCE');
vbar3d empcountry/sumvar=salary type=mean  ;
run;
quit;
ods _all_ close;
title;
/**********************************************************/
/*  Part C - RTF options to print page x of y            */
/**********************************************************/
options nodate nonumber ;
ods rtf path='c:\data\learning labs\ods\output' 
               file='demo2c.rtf ';
ods escapechar '\';  
 title1  j=c  'Page Number in the Title' 
           j=r     'Page \{pageof}'; 
 Footnote j=l         'Page \{pageof}'
                j=c       'In the footnote';
proc tabulate data=demo.employees(obs=120);                           
 class jobcode empcountry;
 var salary;
 table jobcode,salary*(n mean);
 run;
ods rtf close;
/**********************************************************/
/*  Part D - PDF options to print page x of x         */
/**********************************************************/
options nodate nonumber;
ods pdf file='c:\data\learning labs\ods\output\demo2d.pdf' ;           
ods escapechar '\';  
 title1  j=c  'Page Number in the Title' 
           j=r     'Page \{thispage} of \{lastpage}'; 
 Footnote j=l         'Page \{thispage} of \{lastpage}';             
proc tabulate data=demo.employees(obs=120);                           
 class jobcode empcountry;
 var salary;
 table jobcode,salary*(n mean);
 run;
ods pdf close;
