****Demo 3 - Style options with Reporting Procs****;
/*****************************************************/
/*   Use multiple styles for the same report       */ 
/****************************************************/
title; footnote;
ods _all_ close;
ods pdf(id=1) file='file1.pdf' style=sasweb;
ods pdf(id=2) file='file2.pdf' style=seaside;
ods pdf(id=3) file='file3.pdf' style=minimal;


proc print data=demo.employees(obs=10);
run;
ods _all_ close;

/**************************************************/
/* Overriding style attributes in Proc report  */
/*************************************************/
title; footnote;
ods _all_ close;

proc sort data=demo.employees 
           out=employees(rename=(EmpCountry=Country
                                 EmpID=EmployeeID));
   by Jobcode;
   where JobCode contains 'FLTAT';
run;

/* proc format defines a format that will be later mapped to style values in proc report */
/* values low-500000 will be shown in red etc ... */
proc format ;
 value test low-500000='red'
                  500000-1000000='yellow'
				  1000000-high='green';
run;
ods html file='c:\data\learning labs\ods\output\demo3a.html';
ods rtf file='c:\data\learning labs\ods\output\demo3a.rtf';           
ods pdf file='c:\data\learning labs\ods\output\demo3a.pdf';

proc report data=employees nowd ls=100 ps=45
   style(report)={just=left}
   style(header)={font_face='Courier New' font_size=5}
   style(column)={font_face=bookman font_size=5}
   style(summary)={foreground=white background=green};
   title 'Employees Report with Color Coded Salary';
   where JobCode contains 'FLTAT';
   column Country JobCode Salary;
   define Country / group
        style(header)={just=center
	                   foreground=yellow background=green
                       font_face=bookman}
        style(column)={just=left 
	                   foreground=green background=yellow
                       font_face=helvetica};
   define JobCode / group
        style(header)={just=center
                       foreground=pink background=purple 
                       font_face=times font_size=6}
        style(column)={just=left
                       foreground=purple background=pink 
                       font_face=courier font_size=4};
   define salary / sum format=dollar14.
        style(header)={just=center
                       foreground=white background=dark blue 
                       font_style=italic}
        style(column)={just=right 
	                   foreground=dark blue background=white
                       font_weight=bold 
					   /* here is where the column values will be displayed according 
					   		to the color set by the format */
						foreground=test.};
   break after Country /summarize suppress;
   run;
ods _all_ close;

/**************************************************/
/* Overriding style attributes in Proc Print    */
/*************************************************/

proc format ;
 value test low-<20000='red'
                  20000-<30000='yellow'
				  30000-high='green';
run;

ods html file='c:\data\learning labs\ods\output\demo3b.html';
ods rtf file='c:\data\learning labs\ods\output\demo3b.rtf';
ods pdf file='c:\data\learning labs\ods\output\demo3b.pdf';
title;

proc sort data=demo.employees out=employees;
   by Jobcode;
   where empCountry='UNITED KINGDOM' and JobCode contains 'FLTAT';
run;

proc print data=employees
       style(obs)={background=pink 
                   foreground=black}
       style(obsheader)={background=red 
                         foreground=white}
       style(bylabel)={background=white
                     foreground=purple}
       style(total)={background=white};
   title 'PROC PRINT using STYLE=';
   var JobCode EmpID Division  /
      style(header)={background=green
                     foreground=white
                     font_face=Times}
      style(data)={background = white
                   foreground = green
                   font_style=italic};
   var salary /  style(header)={background=green
                     foreground=white
                     font_face=Times}
      style(data)={background = white
	  /* attach traffic lighting here */
                   foreground = test.
                   font_style=italic};
   sum Salary / style(total)=
                    {background=blue
                     foreground=white};
   by JobCode;
run;
ods _all_  close;

/*****************************************************/
/* Overriding style attributes in Proc Tabulate  */
/*****************************************************/

proc format ;
 value test low-<26000='red'
                  26000-<35000='yellow'
				  35000-high='green';
run;
ods html file='c:\data\learning labs\ods\output\demo3c.html';
ods rtf file='c:\data\learning labs\ods\output\demo3c.rtf';
ods pdf file='c:\data\learning labs\ods\output\demo3c.pdf';
title;

proc tabulate data=demo.employees format=dollar10.
              style={background=yellow
                     foreground=blue
                     font_face=courier};
   title 'Flight Attendant Salary Information';
   where JobCode contains 'FLTAT';
   class JobCode / style={background=white
                          foreground=blue
                          font_face=Simplex
                          font_weight=bold
                          font_size=6};                           
   class empCountry / style={background=blue
                          foreground=white
                          font_face=Helv}; 
   var salary / style={background=cyan
                       foreground=black
                       font_face=Times};
   keyword  mean  /
                    style={background=pink
                           foreground=dark blue
                           font_style=italic
                           font_face=helv};
   classlev JobCode / style={background=magenta
                             foreground=white
                             font_face=Arial};
   classlev empCountry / style={background=white
                             foreground=navy
                             font_face=Courier};
			 /* Attach traffic lighting to the mean of salary */
   table JobCode*empCountry,Salary*mean*{s={foreground=test.} }/
            box={label='Information about Salaries'
                    style={background=purple
                           foreground=white
                           font_face=times}};
run;

ods _all_ close;
ods listing;
title;
